You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@commons.apache.org by er...@apache.org on 2015/12/02 15:57:48 UTC

[1/2] [math] MATH-1295

Repository: commons-math
Updated Branches:
  refs/heads/master c4f849335 -> bdc329db9


MATH-1295

Increased default value for number of allowed evaluations.


Project: http://git-wip-us.apache.org/repos/asf/commons-math/repo
Commit: http://git-wip-us.apache.org/repos/asf/commons-math/commit/34646ec9
Tree: http://git-wip-us.apache.org/repos/asf/commons-math/tree/34646ec9
Diff: http://git-wip-us.apache.org/repos/asf/commons-math/diff/34646ec9

Branch: refs/heads/master
Commit: 34646ec9b52192a71e52ffc09cf7fefdd506c48c
Parents: c4f8493
Author: Gilles <er...@apache.org>
Authored: Wed Dec 2 13:51:10 2015 +0100
Committer: Gilles <er...@apache.org>
Committed: Wed Dec 2 13:51:10 2015 +0100

----------------------------------------------------------------------
 src/changes/changes.xml                                          | 4 ++++
 .../org/apache/commons/math4/optim/univariate/BracketFinder.java | 4 ++--
 2 files changed, 6 insertions(+), 2 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/commons-math/blob/34646ec9/src/changes/changes.xml
----------------------------------------------------------------------
diff --git a/src/changes/changes.xml b/src/changes/changes.xml
index 59b55ad..120f9bb 100644
--- a/src/changes/changes.xml
+++ b/src/changes/changes.xml
@@ -54,6 +54,10 @@ If the output is not quite correct, check for invisible trailing spaces!
     </release>
 
     <release version="4.0" date="XXXX-XX-XX" description="">
+      <action dev="erans" type="fix" issue="MATH-1295" due-to="Luke Lindsay">
+        Increased default value for number of allowed evaluations in
+        "o.a.c.m.optim.univariate.BracketFinder".
+      </action>
       <action dev="tn" type="fix" issue="MATH-1294" due-to="Kamil Włodarczyk"> <!-- backported to 3.6 -->
         Fixed potential race condition in PolynomialUtils#buildPolynomial in
         case polynomials are generated from multiple threads. Furthermore, the

http://git-wip-us.apache.org/repos/asf/commons-math/blob/34646ec9/src/main/java/org/apache/commons/math4/optim/univariate/BracketFinder.java
----------------------------------------------------------------------
diff --git a/src/changes/changes.xml b/src/changes/changes.xml
index 120f9bb..28ebacc 100644
--- a/src/changes/changes.xml
+++ b/src/changes/changes.xml
@@ -54,7 +54,7 @@ If the output is not quite correct, check for invisible trailing spaces!
     </release>
 
     <release version="4.0" date="XXXX-XX-XX" description="">
-      <action dev="erans" type="fix" issue="MATH-1295" due-to="Luke Lindsay">
+      <action dev="erans" type="fix" issue="MATH-1295" due-to="Luke Lindsay"> <!-- backported to 3.6 -->
         Increased default value for number of allowed evaluations in
         "o.a.c.m.optim.univariate.BracketFinder".
       </action>
@@ -74,10 +74,10 @@ If the output is not quite correct, check for invisible trailing spaces!
       <action dev="oertl" type="fix" issue="MATH-1269"> <!-- backported to 3.6 -->
         Fixed FastMath.exp that potentially returned NaN for non-NaN argument.
       </action>
-     <action dev="luc" type="add"> <!-- backported to 3.6 -->
-       Added a nth order Brent solver for general real fields, replacing the former
-       solver that was restricted to Dfp fields only.
-     </action>
+      <action dev="luc" type="add"> <!-- backported to 3.6 -->
+        Added a nth order Brent solver for general real fields, replacing the former
+        solver that was restricted to Dfp fields only.
+      </action>
       <action dev="erans" type="add" issue="MATH-1286"> <!-- backported to 3.6 -->
         New "Range" inner class of "o.a.c.m.util.IntegerSequence".
       </action>
diff --git a/src/main/java/org/apache/commons/math4/optim/univariate/BracketFinder.java b/src/main/java/org/apache/commons/math4/optim/univariate/BracketFinder.java
index d2890b9..44e3717 100644
--- a/src/main/java/org/apache/commons/math4/optim/univariate/BracketFinder.java
+++ b/src/main/java/org/apache/commons/math4/optim/univariate/BracketFinder.java
@@ -76,11 +76,11 @@ public class BracketFinder {
     private double fMid;
 
     /**
      * Constructor with default values {@code 100, 50} (see the
      * {@link #BracketFinder(double,int) other constructor}).
      */
     public BracketFinder() {
-        this(100, 50);
+        this(100, 500);
     }
 
     /**


[2/2] [math] Backport tracking.

Posted by er...@apache.org.
Backport tracking.


Project: http://git-wip-us.apache.org/repos/asf/commons-math/repo
Commit: http://git-wip-us.apache.org/repos/asf/commons-math/commit/bdc329db
Tree: http://git-wip-us.apache.org/repos/asf/commons-math/tree/bdc329db
Diff: http://git-wip-us.apache.org/repos/asf/commons-math/diff/bdc329db

Branch: refs/heads/master
Commit: bdc329db9e3428c96498d6864bdee670150a667c
Parents: 34646ec
Author: Gilles <er...@apache.org>
Authored: Wed Dec 2 15:57:13 2015 +0100
Committer: Gilles <er...@apache.org>
Committed: Wed Dec 2 15:57:13 2015 +0100

----------------------------------------------------------------------
 src/changes/changes.xml | 10 +++++-----
 1 file changed, 5 insertions(+), 5 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/commons-math/blob/bdc329db/src/changes/changes.xml
----------------------------------------------------------------------
@@ -76,11 +76,11 @@ public class BracketFinder {
 
     /**
-     * Constructor with default values {@code 100, 50} (see the
+     * Constructor with default values {@code 100, 500} (see the
      * {@link #BracketFinder(double,int) other constructor}).
      */